==> 0.1.8.tar.gz: lib/components/appbar/appbar_custom.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'dart:io' show Platform;
import 'package:npay_component/styles/font_scale.dart';
import 'package:npay_component/styles/colors.dart';

AppBar appBarNomal(BuildContext context, String title,
    {bool showBack = true,
    Widget action,
    Color colorBackground,
    Color colorText}) {
  return AppBar(
    backgroundColor: colorBackground ?? Colors.white,
    centerTitle: Platform.isIOS,
    leading: showBack ? BackButton(color: titleTextColor) : Container(),
    title: Text(
      title,
      style: TextStyle(
          color: colorText ?? titleTextColor,
          fontWeight: FontWeight.w600,
          fontSize: 16),
    ),
    actions: [action != null ? action : Container()],
    brightness: Brightness.light,
  );
}

AppBar appBarExpandTitle(BuildContext context,
    {@required String title,
    @required String subTitle,
    bool showBack = true,
    Widget action,
    Color colorBackground,
    Color colorText}) {
  return AppBar(
    backgroundColor: colorBackground ?? Colors.white,
    centerTitle: Platform.isIOS,
    leading: showBack
        ? BackButton(
            color: titleTextColor,
          )
        : Container(),
    title: Column(
      crossAxisAlignment: Platform.isAndroid
          ? CrossAxisAlignment.start
          : CrossAxisAlignment.center,
      children: [
        Text(title).semiBold16(color: colorText ?? titleTextColor),
        Text(subTitle).regularContext12(color: colorText ?? subTitleTextColor),
      ],
    ),
    actions: [action != null ? action : Container()],
    brightness: Brightness.light,
  );
}

==> 1.0.0.tar.gz: lib/components/appbar/appbar_custom.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'dart:io' show Platform;
import 'package:npay_component/styles/font_scale.dart';
import 'package:npay_component/styles/colors.dart';

AppBar appBarNomal(BuildContext context, String title,
    {bool showBack = true,
    Widget? action,
    Color? colorBackground,
    Color? colorText}) {
  return AppBar(
    backgroundColor: colorBackground ?? Colors.white,
    centerTitle: Platform.isIOS,
    leading: showBack ? BackButton(color: titleTextColor) : Container(),
    title: Text(
      title,
      style: TextStyle(
          color: colorText ?? titleTextColor,
          fontWeight: FontWeight.w600,
          fontSize: 16),
    ),
    actions: [action != null ? action : Container()],
    brightness: Brightness.light,
  );
}

AppBar appBarExpandTitle(BuildContext context,
    {required String title,
    required String subTitle,
    bool showBack = true,
    Widget? action,
    Color? colorBackground,
    Color? colorText}) {
  return AppBar(
    backgroundColor: colorBackground ?? Colors.white,
    centerTitle: Platform.isIOS,
    leading: showBack
        ? BackButton(
            color: titleTextColor,
          )
        : Container(),
    title: Column(
      crossAxisAlignment: Platform.isAndroid
          ? CrossAxisAlignment.start
          : CrossAxisAlignment.center,
      children: [
        Text(title).semiBold16(color: colorText ?? titleTextColor),
        Text(subTitle).regularContext12(color: colorText ?? subTitleTextColor),
      ],
    ),
    actions: [action != null ? action : Container()],
    brightness: Brightness.light,
  );
}
